@@ -24,4 +24,5 @@ def main(get: str):
 if __name__ == '__main__':
     main()
 else:
-    pass
+    print(__name__)
+    main()
